@@ -14,7 +14,7 @@
 """
 from typing import Tuple
 
-from hspylib.core.enums.exit_code import ExitCode
+from hspylib.core.enums.exit_status import ExitStatus
 from hspylib.modules.cli.vt100.terminal import Terminal
 
 
@@ -22,46 +22,46 @@ class GitTools:
     """TODO"""
 
     @staticmethod
-    def top_level_dir() -> Tuple[str, ExitCode]:
+    def top_level_dir() -> Tuple[str, ExitStatus]:
         """TODO"""
         return Terminal.shell_exec('git rev-parse --show-toplevel')
 
     @staticmethod
-    def current_branch() -> Tuple[str, ExitCode]:
+    def current_branch() -> Tuple[str, ExitStatus]:
         """TODO"""
         return Terminal.shell_exec('git symbolic-ref --short HEAD')
 
     @staticmethod
-    def changelog(from_tag: str, to_tag: str) -> Tuple[str, ExitCode]:
+    def changelog(from_tag: str, to_tag: str) -> Tuple[str, ExitStatus]:
         """TODO"""
         return Terminal.shell_exec(f"git log --oneline --pretty='format:%h %ad %s' --date=short {from_tag}^..{to_tag}^")
 
     @staticmethod
-    def unreleased() -> Tuple[str, ExitCode]:
+    def unreleased() -> Tuple[str, ExitStatus]:
         """TODO"""
         latest_tag = Terminal.shell_exec('git describe --tags --abbrev=0 HEAD^')
         return Terminal.shell_exec(f"git log --oneline --pretty='format:%h %ad %s' --date=short '{latest_tag}'..HEAD")
 
     @staticmethod
-    def release_date(tag_name: str) -> Tuple[str, ExitCode]:
+    def release_date(tag_name: str) -> Tuple[str, ExitStatus]:
         """TODO"""
         return Terminal.shell_exec(f"git log -1 --pretty='format:%ad' --date=short {tag_name}")
 
     @staticmethod
-    def tag_list() -> Tuple[str, ExitCode]:
+    def tag_list() -> Tuple[str, ExitStatus]:
         """TODO"""
         return Terminal.shell_exec("git log --tags --simplify-by-decoration --pretty='format:%ci %d'")
 
     @staticmethod
-    def create_tag(version: str, commit_id: str = 'HEAD', description: str = None) -> Tuple[str, ExitCode]:
+    def create_tag(version: str, commit_id: str = 'HEAD', description: str = None) -> Tuple[str, ExitStatus]:
         """TODO"""
         return Terminal.shell_exec(f"git tag -a v{version} {commit_id} -m '{description or version}'")
 
     @staticmethod
-    def search_logs(filter_by: str = '.*') -> Tuple[str, ExitCode]:
+    def search_logs(filter_by: str = '.*') -> Tuple[str, ExitStatus]:
         """TODO"""
         return Terminal.shell_exec(f"git log --grep='{filter_by}' --pretty=format:'%h %ad %s' --date=short")
 
     @staticmethod
-    def show_file(filename: str, commit_id: str = 'HEAD') -> Tuple[str, ExitCode]:
+    def show_file(filename: str, commit_id: str = 'HEAD') -> Tuple[str, ExitStatus]:
         return Terminal.shell_exec(f"git show {commit_id}:{filename}")
